@@ -39,7 +39,10 @@ def makeMasterBias(saveAs, headerToCopyFromName=None, listOfBiasNames=None, list
 # we generate the masterDark by "taking median of the dark frames"
 #   --Richard Berry, James Burnell
 def makeMasterDark(
-    saveAs=None, headerToCopyFromName=None, listOfDarkNames=None, listOfDarkData=None
+    saveAs=None,
+    headerToCopyFromName=None,
+    listOfDarkNames=None,
+    listOfDarkData=None,
 ):
     if listOfDarkNames:
         listOfDarkData = fitDataFromFitImages(listOfDarkNames)
@@ -93,7 +96,7 @@ def makeMasterFlat(
     if not headerToCopyFromName and listOfFlatNames:
         headerToCopyFromName = listOfFlatNames[0]
     elif not headerToCopyFromName and not listOfFlatNames:
-        raise Exception("Filename to copy header from not provied")
+        raise Exception("Filename to copy header from not provided")
 
     firstFlatMedian = customMedian(listOfFlatData[0])
     # We scale all flats w.r.t. first flat image
