@@ -1,11 +1,11 @@
 import math
-from functools import cache
 from typing import Dict, Iterable, Tuple
 
 import numpy as np
 import numpy.typing as npt
 
 from m23.constants import SKY_BG_BOX_REGION_SIZE
+from m23.extract.bg import SkyBgCalculator, circleMatrix
 from m23.file.aligned_combined_file import AlignedCombinedFile
 from m23.file.log_file_combined_file import LogFileCombinedFile
 from m23.file.reference_log_file import ReferenceLogFile
@@ -150,8 +150,8 @@ def flux_log_for_radius(
     We need to optimize this code to work more efficiently with the caller
     function i.e extract_stars
     """
-    regionSize = 64
     pixelsPerStar = np.count_nonzero(circleMatrix(radius))
+    bg_calculator = SkyBgCalculator(image_data)
 
     def fluxSumForStar(position, radius, star_no) -> Tuple[int]:
         """
@@ -161,28 +161,38 @@ def flux_log_for_radius(
         total star flux, background flux and star flux after background
         subtraction respectively
         """
-        # Since we always want a star to fall to the same sky background box, we
-        # calculate which star box it falls into by taking the position from the
-        # reference file not its weighted X, weighted Y that might change.
-
-        # A better method would be to take the average of surrounding boxes
-        # instead because if the sky background noise gets improved because of
-        # equipment change, we'll see a step in new data because of how
-        # difference of much background we were subtracting previously vs now.
-
-        # Note that the reason y, x are reversed is because our x, y in image
-        # data matrix and in the reference file are flipped.
-        y_exact, x_exact = ref.get_star_xy(star_no)
-
         # IDL like round
         x, y = position
         x, y = half_round_up_to_int(x), half_round_up_to_int(y)
 
         starBox = image_data[x - radius : x + radius + 1, y - radius : y + radius + 1]
+
+        # If any of the pixels in starBox is 0, then we assume that we've run
+        # into edge of the image, hence we wash out the ADU value for the star
+        # Note that it's important to check if we've run into edge before we
+        # multiply the starBox with circleMatrix
+        # Might we ever misidentify star not at the edge as one at the edge using
+        # this method?
+        if len(starBox[starBox == 0]) > 0:
+            return (0, 0, 0)
+
         starBox = np.multiply(starBox, circleMatrix(radius))
 
-        backgroundAverageInStarRegion = calculate_star_sky_adu(
-            ref.get_star_xy(star_no), sky_backgrounds, box_width=regionSize
+        # Uncommenting following lines will calculate sky background by making 64 / 64
+        # box and then taking the average of the average sky adu values of the boxes the
+        # star falls under.
+        # regionSize = 64
+        # backgroundAverageInStarRegion = calculate_star_sky_adu(
+        #     ref.get_star_xy(star_no), sky_backgrounds, box_width=regionSize
+        # )
+        # The method below makes a function of how sky background changes across
+        # X, and calculates a unique bg value for each pixel
+
+        star_weighted_y, star_weighted_x = position
+        backgroundAverageInStarRegion = bg_calculator.get_star_average_bg_per_pixel(
+            star_weighted_x,
+            star_weighted_y,
+            radius,
         )
 
         subtractedStarFlux = np.sum(starBox) - backgroundAverageInStarRegion * pixelsPerStar
@@ -204,17 +214,6 @@ def flux_log_for_radius(
     return stars_fluxes
 
 
-@cache
-def circleMatrix(radius):
-    lengthOfSquare = radius * 2 + 1
-    myMatrix = np.zeros(lengthOfSquare * lengthOfSquare).reshape(lengthOfSquare, lengthOfSquare)
-    for row in range(-radius, radius + 1):
-        for col in range(-radius, radius + 1):
-            if math.ceil(math.sqrt((row) ** 2 + (col) ** 2)) <= radius:
-                myMatrix[row + radius][col + radius] = 1
-    return myMatrix
-
-
 def fwhm(data, xweight, yweight, aduPerPixel):
     col_sum = 0
     row_sum = 0
