@@ -10,6 +10,7 @@ from typing_extensions import NotRequired
 
 from m23.constants import (
     CAMERA_CHANGE_2022_DATE,
+    DEFAULT_CPU_FRACTION_USAGE,
     INPUT_CALIBRATION_FOLDER_NAME,
     M23_RAW_IMAGES_FOLDER_NAME,
     TYPICAL_NEW_CAMERA_CROP_REGION,
@@ -18,9 +19,9 @@ from m23.exceptions import InvalidDatetimeInConfig
 from m23.file.log_file_combined_file import LogFileCombinedFile
 from m23.reference import get_reference_files_dict
 from m23.utils import (
+    get_all_fit_files,
     get_darks,
     get_date_from_input_night_folder_name,
-    get_flats,
     get_raw_images,
 )
 
@@ -35,12 +36,17 @@ class ConfigImage(TypedDict):
 class ConfigProcessing(TypedDict):
     no_of_images_to_combine: int
     radii_of_extraction: List[int]
+    image_duration: float
+    dark_prefix: NotRequired[str]
+    cpu_fraction: NotRequired[float]
 
 
 class ConfigInputNight(TypedDict):
     path: str | Path
-    masterflat: NotRequired[str]
-    starttime: NotRequired[str]
+    masterflat: str
+    starttime: NotRequired[datetime.datetime]
+    endtime: NotRequired[datetime.datetime]
+    image_prefix: NotRequired[str]
 
 
 class ConfigInput(TypedDict):
@@ -126,6 +132,14 @@ def create_processing_config(config_dict: Config) -> Config:  # noqa
     radii = list(set(config_dict["processing"]["radii_of_extraction"]))
     config_dict["processing"]["radii_of_extraction"] = radii
 
+    # Set default fraction of processors to use
+    if config_dict["processing"].get("cpu_fraction", None) is None:
+        config_dict["processing"]["cpu_fraction"] = DEFAULT_CPU_FRACTION_USAGE
+
+    # Set default darks and flats
+    if config_dict["processing"].get("dark_prefix", None) is None:
+        config_dict["processing"]["dark_prefix"] = "dark_"
+
     return config_dict
 
 
@@ -136,7 +150,7 @@ def prompt_to_continue(msg: str):
         os._exit(1)
 
 
-def sanity_check_image(config: ConfigImage, night_date: date):  # noqa
+def sanity_check_image(config: ConfigImage, night_date: date, check_crop=True):  # noqa
     """
     Checks for abnormal values in configuration images
     """
@@ -155,41 +169,42 @@ def sanity_check_image(config: ConfigImage, night_date: date):  # noqa
             prompt_to_continue("Detected non 2048 image row value for new camera date")
         if cols != 2048:
             prompt_to_continue("Detected non 2048 image column value for new camera date")
-        if (
-            not crop_region
-            or crop_region
-            and type(crop_region) != list
-            or type(crop_region) == list
-            and len(crop_region) == 0
-        ):
-            prompt_to_continue(
-                "We typically use crop images from new camera, you don't seem to define it"
-            )
-        else:
-            try:
-                for crop_section_index, crop_section in enumerate(crop_region):
-                    for (
-                        section_coordinate_index,
-                        section_coordinate,
-                    ) in enumerate(crop_section):
-                        if (
-                            section_coordinate
-                            != TYPICAL_NEW_CAMERA_CROP_REGION[crop_section_index][
-                                section_coordinate_index
-                            ]
-                        ):
-                            prompt_to_continue(
-                                "Mismatch between default crop region"
-                                + " used in new camera and config file."
-                            )
-                            # Ignore further checking if already made the user
-                            # aware of inconsistency once
-                            return
-
-            except Exception as e:
+        if check_crop:
+            if (
+                not crop_region
+                or crop_region
+                and type(crop_region) != list
+                or type(crop_region) == list
+                and len(crop_region) == 0
+            ):
                 prompt_to_continue(
-                    f"Error while checking crop region with standard crop region value. {e}"
+                    "We typically use crop images from new camera, you don't seem to define it"
                 )
+            else:
+                try:
+                    for crop_section_index, crop_section in enumerate(crop_region):
+                        for (
+                            section_coordinate_index,
+                            section_coordinate,
+                        ) in enumerate(crop_section):
+                            if (
+                                section_coordinate
+                                != TYPICAL_NEW_CAMERA_CROP_REGION[crop_section_index][
+                                    section_coordinate_index
+                                ]
+                            ):
+                                prompt_to_continue(
+                                    "Mismatch between default crop region"
+                                    + " used in new camera and config file."
+                                )
+                                # Ignore further checking if already made the user
+                                # aware of inconsistency once
+                                return
+
+                except Exception as e:
+                    prompt_to_continue(
+                        f"Error while checking crop region with standard crop region value. {e}"
+                    )
 
 
 def sanity_check(config_dict: Config) -> Config:
@@ -224,6 +239,42 @@ def verify_optional_image_options(options: Dict) -> bool:
     return True  # Valid
 
 
+def verify_optional_processing_options(options: Dict) -> bool:
+    """
+    Verifies that the optional processing options are valid
+    """
+    valid_options = ["cpu_fraction", "dark_prefix", "flat_prefix"]
+    for key in options.keys():
+        if key not in valid_options:
+            sys.stderr.write(
+                "Invalid option in processing setting",
+                key,
+                "valid options are",
+                valid_options,
+                "\n",
+            )
+            return False
+    # CPU fraction has to be a number between 0 and 1
+    if cpu_fraction := options.get("cpu_fraction"):
+        if not 0 <= cpu_fraction <= 1:
+            sys.stderr.write(
+                f"CPU fraction has to be a value between 0 and 1. Received: {cpu_fraction}\n"
+            )
+            return False
+
+    dark_prefix = options.get("dark_prefix", "dark_")
+
+    if "flat" in dark_prefix.lower():
+        prompt_to_continue("You have defined 'flat' as dark prefix")
+
+    if "dark" == dark_prefix.lower():
+        prompt_to_continue(
+            "Use dark_prefix like 'dark_' to avoid ambiguity when there are both 'dark' and 'darkf' frames"  # noqa
+        )
+
+    return True
+
+
 def is_night_name_valid(NIGHT_INPUT_PATH: Path):
     """
     Returns if the input night folder name follows naming conventions.
@@ -240,7 +291,7 @@ def is_night_name_valid(NIGHT_INPUT_PATH: Path):
         return False
 
 
-def validate_night(night: ConfigInputNight) -> bool:  # noqa
+def validate_night(night: ConfigInputNight, image_duration: float) -> bool:  # noqa
     """
     Checks whether the input configuration provided for night is valid.
     We check whether the input folders follow the required conventions,
@@ -273,58 +324,102 @@ def validate_night(night: ConfigInputNight) -> bool:  # noqa
         return False
 
     # Check for flats
-    # Either the masterflat should be provided or the night should contain its own flats.
-    if night.get("masterflat"):
-        if not Path(night["masterflat"]).exists():
-            sys.stderr.write(f"Provided masterflat path for {night} doesn't exist.\n")
-            return False
-    # If masterflat isn't provided, the night should have flats to use
-    elif len(list(get_flats(CALIBRATION_FOLDER_PATH))) == 0:
-        sys.stderr.write(
-            f"Night {night} doesn't contain flats in {CALIBRATION_FOLDER_PATH}."
-            + " Provide masterflat path.\n"
-        )
+    # The masterflat should be provided or the night
+    if not night.get("masterflat"):
+        sys.stderr.write(f"Masterflat not provided for {NIGHT_INPUT_PATH}")
+        return False
+
+    if not Path(night["masterflat"]).exists():
+        sys.stderr.write(f"Provided masterflat path for {NIGHT_INPUT_PATH} doesn't exist.\n")
         return False
 
     # Check for darks
-    if len(list(get_darks(CALIBRATION_FOLDER_PATH))) == 0:
+    if len(list(get_darks(CALIBRATION_FOLDER_PATH, image_duration))) == 0:
         sys.stderr.write(
-            f"Night {night} doesn't contain darks in {CALIBRATION_FOLDER_PATH}."
-            + " Cannot continue without darks.\n"
+            f"Night {NIGHT_INPUT_PATH} doesn't contain darks in {CALIBRATION_FOLDER_PATH}"
+            f" for image duration {image_duration}." + " Cannot continue without darks.\n"
         )
         return False
 
     # Check for raw images
     try:
-        if len(list(get_raw_images(M23_FOLDER_PATH))) == 0:
-            sys.stderr.write(f"Night {night} doesn't have raw images in {M23_FOLDER_PATH}.\n")
-            return False
+        # Check if the user has defined raw image prefix
+        if raw_img_prefix := night.get("image_prefix"):
+            if (
+                len(
+                    list(get_all_fit_files(M23_FOLDER_PATH, image_duration, prefix=raw_img_prefix))
+                )
+                == 0
+            ):
+                sys.stderr.write(
+                    f"Night {NIGHT_INPUT_PATH} doesn't have raw images in {M23_FOLDER_PATH}."
+                    f" for image duration {image_duration}\n"
+                )
+                return False
+        else:
+            if len(list(get_raw_images(M23_FOLDER_PATH, image_duration))) == 0:
+                sys.stderr.write(
+                    f"Night {NIGHT_INPUT_PATH} doesn't have raw images in {M23_FOLDER_PATH}."
+                    f" for image duration {image_duration}\n"
+                )
+                return False
     except ValueError as e:
         sys.stderr.write(
-            "Raw image in night {night} doesn't confirm to 'something-00x.fit' convention.\n"
+            "Raw image in night {NIGHT_INPUT_PATH} doesn't confirm to 'something-00x.fit' convention.\n"  # noqa
         )
         raise e
 
+    night_date = get_date_from_input_night_folder_name(Path(night.get("path")).name)
     # Validate the start and end time of observation if provided
     # Check if datetime is declared
     if start := night.get("starttime"):
         try:
-            validate_datetime(start)
-        except InvalidDatetimeInConfig as e:
+            night["starttime"] = validate_datetime(start)
+        except InvalidDatetimeInConfig:
             sys.stderr.write(
-                f"OPTIONAL observation start time for {night} isn't"
-                " in the format  1979-05-27T07:32:00 where timezone is UT\n"
+                f"OPTIONAL observation start time for {NIGHT_INPUT_PATH} isn't"
+                " in the format  YYYY-mm-ddTHH:MM:SS where timezone is UT\n"
             )
-            raise e
+            return False
+
+    if end := night.get("endtime"):
+        try:
+            night["endtime"] = validate_datetime(end)
+        except InvalidDatetimeInConfig:
+            sys.stderr.write(
+                f"OPTIONAL observation end time for {NIGHT_INPUT_PATH} isn't"
+                " in the format  YYYY-mm-ddTHH:MM:SS where timezone is UT\n"
+            )
+            return False
+
+    start_time = night.get("starttime")
+    end_time = night.get("endtime")
+    if start_time and end_time:
+        # Start time must come before end_time
+        assert start_time < end_time
+        if (end_time - start_time).seconds < 60 * 60:
+            prompt_to_continue(f"Start time and end time are within an hour for {night_date}.")
+    if start_time:
+        if abs((start_time.date() - night_date).days) > 3:
+            sys.stderr.write(
+                f"Starttime for night {night_date} is off night_date by more than 3 days.\n"
+            )
+            return False
+    if end_time:
+        if abs((end_time.date() - night_date).days) > 3:
+            sys.stderr.write(
+                f"Endtime for night {end_time}  is off night_date by more than 3 days.\n"
+            )
+            return False
 
     return True  # Assuming we did the best we could to catch errors
 
 
-def validate_input_nights(list_of_nights: List[ConfigInputNight]) -> bool:
+def validate_input_nights(list_of_nights: List[ConfigInputNight], image_duration: float) -> bool:
     """
     Returns True if input for all nights is valid, False otherwise.
     """
-    return all([validate_night(night) for night in list_of_nights])
+    return all([validate_night(night, image_duration) for night in list_of_nights])
 
 
 def validate_reference_files(
@@ -368,8 +463,14 @@ def validate_reference_files(
 
 
 def validate_datetime(time_obj):
+    if isinstance(time_obj, str):
+        try:
+            time_obj = datetime.datetime.strptime(time_obj, "%Y-%m-%dT%H:%M:%S")
+        except ValueError:
+            raise InvalidDatetimeInConfig
     if not isinstance(time_obj, datetime.datetime):
         raise InvalidDatetimeInConfig
+    return time_obj
 
 
 def verify_optional_output_options(output_options: Dict[str, any]):
@@ -397,6 +498,15 @@ def verify_optional_output_options(output_options: Dict[str, any]):
     return True
 
 
+def sanity_check_no_of_images_to_combine(no_of_images_to_combine: int, image_duration: float):
+    if int(70 / image_duration) != no_of_images_to_combine:
+        prompt_to_continue(
+            f"You have said to combine {no_of_images_to_combine}"
+            f" but image duration is {image_duration}."
+        )
+    return True
+
+
 def validate_file(file_path: Path, on_success: Callable[[Config], None]) -> None:
     """
     This method reads data processing configuration from the file path
@@ -415,8 +525,10 @@ def validate_file(file_path: Path, on_success: Callable[[Config], None]) -> None
                 **optional_image_options,
             },
             "processing": {
-                "no_of_images_to_combine": int(_),
+                "no_of_images_to_combine": int(no_of_images_to_combine),
                 "radii_of_extraction": list(radii_of_extraction),
+                "image_duration": float(image_duration),
+                **optional_processing_options,
             },
             "reference": {
                 "image": str(reference_image),
@@ -426,25 +538,31 @@ def validate_file(file_path: Path, on_success: Callable[[Config], None]) -> None
             },
             "input": {"nights": list(list_of_nights)},
             "output": {"path": str(_), **optional_output_options},
-        } if (
-            verify_optional_image_options(optional_image_options)
-            and verify_optional_output_options(optional_output_options)
-            and is_valid_radii_of_extraction(radii_of_extraction)
-            and validate_input_nights(list_of_nights)
-            and validate_reference_files(
-                reference_image,
-                reference_file,
-                color_ref_file,
-                logfile,
-                radii_of_extraction,
-            )
-        ):
-            # Check for the optional configurations
-            # Optional configs should either not be declared or be
-            # correctly declared
-            on_success(sanity_check(create_processing_config(configuration)))
+        }:
+            if (
+                sanity_check_no_of_images_to_combine(no_of_images_to_combine, image_duration)
+                and verify_optional_image_options(optional_image_options)
+                and verify_optional_processing_options(optional_processing_options)
+                and verify_optional_output_options(optional_output_options)
+                and is_valid_radii_of_extraction(radii_of_extraction)
+                and validate_input_nights(list_of_nights, image_duration)
+                and validate_reference_files(
+                    reference_image,
+                    reference_file,
+                    color_ref_file,
+                    logfile,
+                    radii_of_extraction,
+                )
+            ):
+                # Check for the optional configurations
+                # Optional configs should either not be declared or be
+                # correctly declared
+                on_success(sanity_check(create_processing_config(configuration)))
         case _:
-            sys.stderr.write("Invalid format.\n")
+            sys.stderr.write(
+                "Stopping. You're missing some required options in your toml"
+                " or the format isn't valid.\n"
+            )
 
 
 def load_configuration_with_necessary_reference_files(configuration, pop=None):
