@@ -21,23 +21,33 @@ def generate_masterflat_auxiliary(config: MasterflatGeneratorConfig) -> None:
     """
     Generates masterflat based on the configuration provided
     this function assumes that the configuration provided is valid as it
-    should be only calledfrom generate_master_flat that checks for the validity
+    should be only called from generate_master_flat that checks for the validity
     of the configuration file before calling this function.
     """
     rows, cols = config["image"]["rows"], config["image"]["columns"]
-    crop_region = config["image"].get("crop_region", [])
+    image_duration = config["image_duration"]
+    dark_prefix = config["dark_prefix"]
+    flat_prefix = config["flat_prefix"]
     NIGHT_INPUT_CALIBRATION_FOLDER = config["input"] / INPUT_CALIBRATION_FOLDER_NAME
     # Note the order is important when generating masterflat
-    flats = fit_data_from_fit_images(sorted_by_number(get_flats(NIGHT_INPUT_CALIBRATION_FOLDER)))
-    darks = fit_data_from_fit_images(get_darks(NIGHT_INPUT_CALIBRATION_FOLDER))
+    flats = fit_data_from_fit_images(
+        sorted_by_number(
+            get_flats(NIGHT_INPUT_CALIBRATION_FOLDER, image_duration, prefix=flat_prefix)
+        )
+    )
+    darks = fit_data_from_fit_images(
+        get_darks(NIGHT_INPUT_CALIBRATION_FOLDER, image_duration, prefix=dark_prefix)
+    )
     night_date = get_date_from_input_night_folder_name(config["input"])
 
-    # Crop images if crop region is defined
-    if len(crop_region) > 0:
-        flats = [crop(matrix, rows, cols) for matrix in flats]
+    # Crop extra region from the darks and flats. Note this is different from
+    # the crop_region that's defined in image options for process. More than
+    # crop, it's a fill that fills out the vignetting ring with zero values
+    darks = [crop(matrix, rows, cols) for matrix in darks]
+    flats = [crop(matrix, rows, cols) for matrix in flats]
 
     # We have to first create master dark before creating masterflat
-    # as masteflat requires masterdark. Note that we're passing saveAs
+    # as masterflat requires masterdark. Note that we're passing saveAs
     # as None because we don't want to save the masterdark created in this
     # process
     masterDarkData = makeMasterDark(
@@ -45,7 +55,7 @@ def generate_masterflat_auxiliary(config: MasterflatGeneratorConfig) -> None:
     )
 
     # Make master flat
-    filename = MasterflatFile.generate_file_name(night_date)
+    filename = MasterflatFile.generate_file_name(night_date, image_duration)
     save_file_path = config["output"] / filename
 
     makeMasterFlat(
