@@ -3,23 +3,28 @@ from pathlib import Path
 from typing import Callable, TypedDict
 
 import toml
+from typing_extensions import NotRequired
 
 from m23.constants import INPUT_CALIBRATION_FOLDER_NAME
 from m23.processor.config_loader import (
     ConfigImage,
     is_night_name_valid,
+    prompt_to_continue,
     sanity_check_image,
 )
-from m23.utils import get_date_from_input_night_folder_name, get_flats
+from m23.utils import get_darks, get_date_from_input_night_folder_name, get_flats
 
 
 class MasterflatGeneratorConfig(TypedDict):
+    dark_prefix: NotRequired[str]
+    flat_prefix: NotRequired[str]
     input: Path | str
     output: Path | str
     image: ConfigImage
+    image_duration: float
 
 
-def is_valid(config: MasterflatGeneratorConfig) -> bool:
+def is_valid(config: MasterflatGeneratorConfig) -> bool:  # noqa
     """
     Returns whether the configuration file is valid
     """
@@ -39,10 +44,35 @@ def is_valid(config: MasterflatGeneratorConfig) -> bool:
         sys.stderr.write(f"Calibration folder {CALIBRATION_FOLDER_PATH} doesn't exist.\n")
         return False
 
-    # Verify that the night contains flats to use
-    if len(list(get_flats(CALIBRATION_FOLDER_PATH))) == 0:
+    # Verify that the image duration is a float
+    if type(config["image_duration"]) not in [float, int]:
+        sys.stderr.write(f"Image duration has to be a float. Got {config['image_duration']}\n")
+        return False
+
+    image_duration = config["image_duration"]
+
+    dark_prefix = config.get("dark_prefix", "dark")
+    flat_prefix = config.get("flat_prefix", "flat")
+    config["dark_prefix"] = dark_prefix
+    config["flat_prefix"] = flat_prefix
+
+    if "flat" in dark_prefix.lower():
+        prompt_to_continue("You have defined 'flat' as dark prefix")
+
+    if "dark" in flat_prefix.lower():
+        prompt_to_continue("You have defined 'dark' as flat prefix")
+
+    # Verify that the night contains darks to use
+    if len(list(get_darks(CALIBRATION_FOLDER_PATH, image_duration, prefix=dark_prefix))) == 0:
         sys.stderr.write(
-            f"Night {NIGHT_INPUT_PATH} doesn't contain flats in {CALIBRATION_FOLDER_PATH}. Provide masterflat path.\n"  # noqa ES501
+            f"Night {NIGHT_INPUT_PATH} doesn't contain {dark_prefix} for image duration of {image_duration} in {CALIBRATION_FOLDER_PATH}.\n"  # noqa ES501
+        )
+        return False
+
+    # Verify that the night contains flats to use
+    if len(list(get_flats(CALIBRATION_FOLDER_PATH, image_duration, prefix=flat_prefix))) == 0:
+        sys.stderr.write(
+            f"Night {NIGHT_INPUT_PATH} doesn't contain {flat_prefix} for image duration of {image_duration} in {CALIBRATION_FOLDER_PATH}.\n"  # noqa ES501
         )
         return False
 
@@ -109,7 +139,9 @@ def sanity_check(config: MasterflatGeneratorConfig) -> MasterflatGeneratorConfig
     This method is warn about technically correct but abnormal configuration values
     """
     night_date = get_date_from_input_night_folder_name(config["input"])
-    sanity_check_image(config["image"], night_date)
+    # Since we dont crop out (meaning fill the vignetting ring with bogus values)
+    # in the case of masterdark and masterflat, its not necessary to check it
+    sanity_check_image(config["image"], night_date, check_crop=False)
     return config
 
 
@@ -129,7 +161,8 @@ def validate_generate_masterflat_config_file(
             "input": _,
             "output": _,
             "image": {"rows": int(_), "columns": int(_)},
-        } as masterflat_generator_config if is_valid(masterflat_generator_config):
-            on_success(sanity_check(create_enhanced_config(masterflat_generator_config)))
+        } as masterflat_generator_config:
+            if is_valid(masterflat_generator_config):
+                on_success(sanity_check(create_enhanced_config(masterflat_generator_config)))
         case _:
             sys.stderr.write("Invalid format.\n")
